import React, {Component} from 'react'
import { ConfigProvider } from 'antd'
import enUS from 'antd/es/locale/en_US'
import zhCN from 'antd/es/locale/zh_CN'

import asyncComponent from '@/utils/asyncComponent'
import Header from '@/components/header'
import MKEmitter from '@/utils/events.js'
import Sidemenu from '@/components/sidemenu'
import QueryLog from '@/components/querylog'
import ImgScale from '@/components/imgScale'

import './index.scss'

const Tabview = asyncComponent(() => import('@/components/tabview'))
const Breadview = asyncComponent(() => import('@/components/breadview'))
const _locale = sessionStorage.getItem('lang') !== 'en-US' ? zhCN : enUS

class Main extends Component {
  state = {
    navBar: window.GLOB.navBar
  }

  componentDidMount () {
    MKEmitter.addListener('resetSelectLine', this.resetParentParam)
  }

  componentWillUnmount () {
    MKEmitter.removeListener('resetSelectLine', this.resetParentParam)
  }

  resetParentParam = (MenuID, id, data) => {
    window.GLOB.CacheData.set(MenuID, {...data, $BID: id})
  }

  render () {
    const { navBar } = this.state
    const isSideMenu = !['linkage_navigation', 'linkage', 'menu_board'].includes(navBar)

    return (
      <div className="mk-main-view">
        <ConfigProvider locale={_locale}>
          <Header key="header"/>
          {isSideMenu && navBar !== 'menu_board_navigation' ? <Sidemenu key="sidemenu"/> : null}
          {isSideMenu ? <Tabview key="tabview"/> : null}
          {!isSideMenu ? <Breadview key="breadview"/> : null}
          <QueryLog />
        </ConfigProvider>
        <ImgScale />
      </div>
    )
  }
}

export default Main